@@ -2370,10 +2370,68 @@ void gok_scanner_input_motion (gint *motion_data, gint n_axes)
 		}
 		m_pContainingKey = pKey;
 	}
-	gok_keyboard_paint_pointer (pKeyboard, 
-				    pWindow, x, y);
+	gok_keyboard_paint_pointer (pKeyboard, pWindow, x, y);
 }
 
+/**
+* gok_scanner_input_motion_libusb
+* @x: Horizontal (first axis) input device motion component.
+* @y: Vertical (second axis)  input device motion component.
+*
+* Handler for input device motion events generated by an input device accessed through libusb. 
+**/
+void gok_scanner_input_motion_libusb (gint x, gint y)
+{
+	GokKey *pKey;
+	gint w, h;
+	gint slop = gok_scanner_get_slop();
+	static gint offset_x = 0;
+	static gint offset_y = 0;
+	GokKeyboard *pKeyboard = gok_main_get_current_keyboard ();
+	GtkWidget *pWindow = gok_main_get_main_window ();
+	
+	gdouble multiplier = gok_data_get_valuator_sensitivity ();
+	x = x * multiplier;
+	y = y * multiplier;
+
+	/* clip coordinates to window */
+	gdk_drawable_get_size (pWindow->window, &w, &h);
+	/* horizontal */
+	if (w + slop < offset_x + x) {
+	        /* too far right */
+		x = w + slop - offset_x;
+	} else if (offset_x + x < -slop) {
+   	        /* too far left */
+		x = - offset_x - slop;
+	}
+	/* vertical */
+	if (h + slop < offset_y + y) {
+	        /* too far below */
+		y = h + slop - offset_y;
+	} else if (offset_y + y < -slop) {
+	        /* too far above */
+		y = -offset_y - slop;
+	}
+
+	offset_x += x;
+	offset_y += y;
+
+   	pKey = gok_keyboard_find_key_at (pKeyboard, offset_x, offset_y, m_pContainingKey);
+   	gok_keyboard_unpaint_pointer (pKeyboard, pWindow);
+	if (m_pContainingKey != pKey) {
+		gok_scanner_on_key_leave (m_pContainingKey);
+		if (pKey) {
+			gok_scanner_on_key_enter (pKey);
+		}
+		else if (m_pContainingKey) {
+		        gok_scanner_on_key_leave (m_pContainingKey);
+		}
+		m_pContainingKey = pKey;
+	}
+	gok_keyboard_paint_pointer (pKeyboard, pWindow, offset_x, offset_y);
+}
+
+
 /**
 * gok_scanner_on_timer1
 * @data: Pointer to the user data associated with the timer.
