@@ -51,10 +51,15 @@ typedef struct _GokApplicationClass {
   LoginHelperClass     parent_class;
 } GokApplicationClass;
 
+struct gok_window_realize_data {
+	gboolean is_dock;
+	gboolean use_libusb;
+};
+
 /* public */
 GType      gok_application_get_type (void) G_GNUC_CONST;
 
-GtkWidget* gok_main_create_window (gboolean is_dock);
+GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realize_data);
 void gok_main_set_cursor (GdkCursor *cursor);
 gint gok_main_open(gint argc, gchar *argv[]);
 void gok_main_raise_window (void);
@@ -99,13 +104,14 @@ void gok_main_center_corepointer (GtkWidget *widget);
 void gok_main_app_change_listener (Accessible* pAccessible);
 void gok_main_window_change_listener (Accessible* pAccessible);
 void gok_main_motion_listener (gint n_axes, int *motion_data, long mods, long timestamp);
-void gok_main_button_listener (gint button, gint state, long mods, long timestamp);
+void gok_main_button_listener (gint button, gint state, long mods, long timestamp, gboolean using_libusb);
 void gok_main_mouse_button_listener (gint button, gint state, long mods, long timestamp);
 void gok_main_close (void);
 gboolean gok_main_get_use_geometry (void);
 void gok_main_get_geometry (GdkRectangle* pRectangle);
 void gok_main_update_struts (gint width, gint height, gint x, gint y);
 void gok_main_set_wm_dock (gboolean is_dock);
+gboolean gok_main_get_debug_nameless (void);
 
 #ifdef __cplusplus
 }
